# Python Cryptobox

A cffi wrapper for [Cryptobox - C API](https://github.com/wireapp/cryptobox-c),
the encryption library of the [Wire-Messenger](https://wire.com)

## Installation

```pip install python-cryptobox```

## Addition Requirements
You need apart from the python dependencies:

- gcc
- cryptobox-c
- Linux

## Thank
This project wouldn't be possible without [Felix Pechtl](https://github.com/Fi0x) and
[Kai Wiest](https://github.com/Gametunes) and their 
[UniMessanger](https://github.com/Fi0x/UniMessenger) project.

## Disclaimer
There is no guarantee in any means that this library is secure.

The name "Wire" is a trademark of Wire Swiss GmbH.
There is no association of this project with the Wire Swiss GmbH.
This project is developed independently as a hobby.

## Licence

The project itself and cryptobox-c are GPLv3 licenced.

    Copyright (C) 2021 Alexander Eisele

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
